@@ -19,6 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this package. If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
+#define QT_USE_QSTRINGBUILDER
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
@@ -32,15 +33,21 @@
 #include <QShortcut>
 #include <QTextStream>
 #include <QTimer>
+#include <QtConcurrent>
 
 #include "about.h"
 #include "common.h"
 #include "service.h"
 
+#include <algorithm>
 #include <chrono>
 
 using namespace std::chrono_literals;
 
+namespace {
+constexpr int kTooltipFetchedRole = Qt::UserRole + 1;
+}
+
 MainWindow::MainWindow(QWidget *parent)
     : QDialog(parent),
       ui(new Ui::MainWindow)
@@ -60,12 +67,12 @@ MainWindow::MainWindow(QWidget *parent)
             centerWindow();
         }
     }
-    if (initSystem != "systemd"
-        && !initSystem.startsWith("init")) { // Can be "init(mxlinux)" when running in WSL for example
+    if (initSystem != QLatin1String("systemd")
+        && !initSystem.startsWith(QLatin1String("init"))) { // Can be "init(mxlinux)" when running in WSL for example
         QMessageBox::warning(
             this, tr("Error"),
             tr("Could not determine the init system. This program is supposed to run either with systemd or sysvinit")
-                + "\nINIT:" + initSystem);
+                % "\nINIT:" % initSystem);
     }
     QPalette palette = ui->listServices->palette();
     defaultForeground = palette.color(QPalette::Text);
@@ -95,10 +102,23 @@ MainWindow::MainWindow(QWidget *parent)
         ui->listServices->setFocus();
     });
     connect(ui->listServices, &QListWidget::itemEntered, this, [this](QListWidgetItem *item) {
-        if (auto service = item->data(Qt::UserRole).value<Service *>()) {
-            if (item->toolTip().isEmpty()) {
-                const QString description = service->getDescription();
-                item->setToolTip(description);
+        // Cancel any pending tooltip
+        cancelPendingTooltip();
+
+        if (item->data(Qt::UserRole).value<Service *>()) {
+            if (item->toolTip().isEmpty() && !item->data(kTooltipFetchedRole).toBool()) {
+                pendingTooltipIndex = ui->listServices->indexFromItem(item);
+                if (!pendingTooltipIndex.isValid()) {
+                    return;
+                }
+
+                // Start tooltip timer with delay
+                if (!tooltipTimer) {
+                    tooltipTimer = new QTimer(this);
+                    tooltipTimer->setSingleShot(true);
+                    connect(tooltipTimer, &QTimer::timeout, this, &MainWindow::fetchTooltipDescription);
+                }
+                tooltipTimer->start(300); // 300ms delay
             }
         }
     });
@@ -113,6 +133,10 @@ MainWindow::MainWindow(QWidget *parent)
 MainWindow::~MainWindow()
 {
     settings.setValue("geometry", saveGeometry());
+    if (tooltipWatcher) {
+        tooltipWatcher->cancel();
+        tooltipWatcher->waitForFinished();
+    }
     delete ui;
 }
 
@@ -176,7 +200,15 @@ void MainWindow::cmdDone()
 void MainWindow::setGeneralConnections() noexcept
 {
     connect(ui->comboFilter, &QComboBox::currentTextChanged, this, &MainWindow::displayServices);
-    connect(ui->lineSearch, &QLineEdit::textChanged, this, &MainWindow::displayServices);
+    connect(ui->lineSearch, &QLineEdit::textChanged, this, [this]() {
+        // Debounce search to prevent excessive updates
+        if (!searchTimer) {
+            searchTimer = new QTimer(this);
+            searchTimer->setSingleShot(true);
+            connect(searchTimer, &QTimer::timeout, this, &MainWindow::displayServices);
+        }
+        searchTimer->start(150); // 150ms delay
+    });
     connect(ui->listServices, &QListWidget::currentItemChanged, this, &MainWindow::onSelectionChanged);
     connect(ui->pushAbout, &QPushButton::clicked, this, &MainWindow::pushAbout_clicked);
     connect(ui->pushCancel, &QPushButton::pressed, this, &MainWindow::close);
@@ -186,6 +218,159 @@ void MainWindow::setGeneralConnections() noexcept
     connect(ui->pushStartStop, &QPushButton::clicked, this, &MainWindow::pushStartStop_clicked);
 }
 
+void MainWindow::cancelPendingTooltip()
+{
+    if (tooltipTimer) {
+        tooltipTimer->stop();
+    }
+    pendingTooltipIndex = QPersistentModelIndex();
+}
+
+void MainWindow::fetchTooltipDescription()
+{
+    if (!pendingTooltipIndex.isValid() || tooltipInProgress) {
+        return;
+    }
+
+    QListWidgetItem *item = ui->listServices->itemFromIndex(pendingTooltipIndex);
+    if (!item) {
+        pendingTooltipIndex = QPersistentModelIndex();
+        return;
+    }
+
+    auto *service = item->data(Qt::UserRole).value<Service *>();
+    if (!service) {
+        pendingTooltipIndex = QPersistentModelIndex();
+        return;
+    }
+
+    tooltipInProgress = true;
+    activeTooltipIndex = pendingTooltipIndex;
+    pendingTooltipIndex = QPersistentModelIndex();
+    activeTooltipService = service;
+
+    if (!tooltipWatcher) {
+        tooltipWatcher = new QFutureWatcher<QString>(this);
+        connect(tooltipWatcher, &QFutureWatcher<QString>::finished, this, [this]() {
+            const QString description = tooltipWatcher->result();
+            QListWidgetItem *activeItem = ui->listServices->itemFromIndex(activeTooltipIndex);
+            const bool serviceValid = activeTooltipService
+                && std::any_of(services.begin(), services.end(),
+                               [this](const auto &svc) { return svc.get() == activeTooltipService; });
+
+            if (activeItem && activeItem->listWidget() && activeTooltipIndex.isValid() && serviceValid) {
+                if (!description.isEmpty()) {
+                    activeItem->setToolTip(description);
+                }
+                activeItem->setData(kTooltipFetchedRole, true);
+            }
+
+            tooltipInProgress = false;
+            activeTooltipIndex = QPersistentModelIndex();
+            activeTooltipService = nullptr;
+            if (pendingTooltipIndex.isValid()) {
+                fetchTooltipDescription();
+            }
+        });
+    }
+
+    tooltipWatcher->setFuture(QtConcurrent::run([service]() { return service->getDescription(); }));
+}
+
+std::optional<QString> MainWindow::sanitizeServiceName(const QString &rawName)
+{
+    const QLatin1String dotSeparator(".");
+    QString name = rawName.section(dotSeparator, 0, 0);
+    name = name.simplified();
+    name = decodeEscapeSequences(name);
+
+    static const QRegularExpression invalidRegex("[^a-zA-Z0-9._@:+-]");
+    if (name.isEmpty() || name.length() > 100 || name.contains(invalidRegex)) {
+        return std::nullopt;
+    }
+
+    return name;
+}
+
+QSet<QString> MainWindow::loadSystemdEnabledServices(bool isUserService)
+{
+    QString cmdStr = "systemctl list-unit-files --type=service --state=enabled -o json";
+    if (isUserService) [[unlikely]] {
+        cmdStr = "systemctl --user list-unit-files --type=service --state=enabled -o json";
+    }
+    const auto enabled = cmd.getOut(cmdStr).trimmed();
+    auto doc = QJsonDocument::fromJson(enabled.toUtf8());
+    if (!doc.isArray()) {
+        qDebug() << "JSON data is not an array for enabled services.";
+        return {};
+    }
+
+    QSet<QString> enabledNames;
+    const auto jsonArray = doc.array();
+    enabledNames.reserve(jsonArray.size());
+
+    const QLatin1String unitFileKey("unit_file");
+    for (const auto &value : jsonArray) {
+        if (!value.isObject()) [[unlikely]] {
+            continue;
+        }
+        const auto obj = value.toObject();
+        if (const auto name = sanitizeServiceName(obj.value(unitFileKey).toString())) {
+            enabledNames.insert(*name);
+        }
+    }
+
+    return enabledNames;
+}
+
+QString MainWindow::decodeEscapeSequences(const QString &input)
+{
+    static const QRegularExpression hexRegex("\\\\x([0-9a-fA-F]{2})");
+    static const QRegularExpression unicodeRegex("\\\\u([0-9a-fA-F]{4})");
+    static const QRegularExpression octalRegex("\\\\([0-7]{1,3})");
+    static const QRegularExpression backslashCleanup("\\\\(?![0-7]{1,3}|[xu][0-9a-fA-F]+)");
+
+    QString result = input;
+
+    // Decode \xXX sequences (hex)
+    QRegularExpressionMatchIterator hexIt = hexRegex.globalMatch(result);
+    while (hexIt.hasNext()) {
+        QRegularExpressionMatch match = hexIt.next();
+        bool ok;
+        int hexValue = match.captured(1).toInt(&ok, 16);
+        if (ok) {
+            result.replace(match.captured(0), QChar(hexValue));
+        }
+    }
+
+    // Decode \uXXXX sequences (Unicode)
+    QRegularExpressionMatchIterator unicodeIt = unicodeRegex.globalMatch(result);
+    while (unicodeIt.hasNext()) {
+        QRegularExpressionMatch match = unicodeIt.next();
+        bool ok;
+        int unicodeValue = match.captured(1).toInt(&ok, 16);
+        if (ok) {
+            result.replace(match.captured(0), QChar(unicodeValue));
+        }
+    }
+
+    // Decode \OOO sequences (octal)
+    QRegularExpressionMatchIterator octalIt = octalRegex.globalMatch(result);
+    while (octalIt.hasNext()) {
+        QRegularExpressionMatch match = octalIt.next();
+        bool ok;
+        int octalValue = match.captured(1).toInt(&ok, 8);
+        if (ok) {
+            result.replace(match.captured(0), QChar(octalValue));
+        }
+    }
+
+    // Remove any remaining backslashes that aren't part of valid escape sequences
+    result = result.remove(backslashCleanup);
+
+    return result;
+}
+
 QString MainWindow::getHtmlColor(const QColor &color) noexcept
 {
     return QString("#%1%2%3")
@@ -197,7 +382,7 @@ QString MainWindow::getHtmlColor(const QColor &color) noexcept
 void MainWindow::listServices()
 {
     services.clear();
-    if (initSystem != "systemd") {
+    if (initSystem != QLatin1String("systemd")) {
         processNonSystemdServices();
     } else {
         processSystemdServices();
@@ -206,8 +391,8 @@ void MainWindow::listServices()
 
 void MainWindow::processNonSystemdServices()
 {
+    static const QRegularExpression dpkgRegex("dpkg-.*$");
     const auto list = cmd.getOutAsRoot("/sbin/service --status-all", true).trimmed().split("\n");
-    QRegularExpression re("dpkg-.*$");
     services.reserve(list.size());
 
     const QLatin1String sectionDelimiter("]  ");
@@ -216,7 +401,7 @@ void MainWindow::processNonSystemdServices()
 
     for (const auto &item : list) {
         const QString trimmedItem = item.trimmed();
-        if (item.section(sectionDelimiter, 1) == debian || trimmedItem.contains(re)) {
+        if (item.section(sectionDelimiter, 1) == debian || trimmedItem.contains(dpkgRegex)) {
             continue;
         }
 
@@ -226,20 +411,31 @@ void MainWindow::processNonSystemdServices()
         }
 
         bool enabled = dependTargets.contains(name) || Service::isEnabled(name);
-        services.append(QSharedPointer<Service>::create(name, trimmedItem.startsWith(runningPrefix), enabled));
+        services.append(QSharedPointer<Service>::create(name, trimmedItem.startsWith(runningPrefix), enabled, false));
     }
 }
 
 void MainWindow::processSystemdServices()
 {
     QStringList names;
-    processSystemdActiveInactiveServices(names);
-    processSystemdMaskedServices(names);
+    const QSet<QString> enabledSystemServices = loadSystemdEnabledServices(false);
+    const QSet<QString> enabledUserServices = loadSystemdEnabledServices(true);
+
+    processSystemdActiveInactiveServices(names, enabledSystemServices, false); // System services
+    processSystemdMaskedServices(names, false); // System services
+    processSystemdActiveInactiveServices(names, enabledUserServices, true); // User services
+    processSystemdMaskedServices(names, true); // User services
 }
 
-void MainWindow::processSystemdActiveInactiveServices(QStringList &names)
+void MainWindow::processSystemdActiveInactiveServices(QStringList &names,
+                                                      const QSet<QString> &enabledServices,
+                                                      bool isUserService)
 {
-    const auto list = cmd.getOut("systemctl list-units --type=service --all -o json").trimmed();
+    QString cmdStr = "systemctl list-units --type=service --all -o json";
+    if (isUserService) [[unlikely]] {
+        cmdStr = "systemctl --user list-units --type=service --all -o json";
+    }
+    const auto list = cmd.getOut(cmdStr).trimmed();
     auto doc = QJsonDocument::fromJson(list.toUtf8());
     if (!doc.isArray()) {
         qDebug() << "JSON data is not an array for service units.";
@@ -255,35 +451,40 @@ void MainWindow::processSystemdActiveInactiveServices(QStringList &names)
     const QLatin1String unitKey("unit");
     const QLatin1String loadKey("load");
     const QLatin1String subKey("sub");
-    const QLatin1String dotSeparator(".");
     const QLatin1String notFoundValue("not-found");
     const QLatin1String runningValue("running");
 
     for (const auto &value : jsonArray) {
-        if (!value.isObject()) {
+        if (!value.isObject()) [[unlikely]] {
             continue;
         }
 
         const auto obj = value.toObject();
-        const QString name = obj.value(unitKey).toString().section(dotSeparator, 0, 0);
+        const auto nameOpt = sanitizeServiceName(obj.value(unitKey).toString());
 
-        if (name.isEmpty() || nameSet.contains(name) || obj.value(loadKey).toString() == notFoundValue) {
+        if (!nameOpt || nameSet.contains(*nameOpt) || obj.value(loadKey).toString() == notFoundValue) [[unlikely]] {
             continue;
         }
 
+        const QString &name = *nameOpt;
         nameSet.insert(name);
 
         const bool isRunning = (obj.value(subKey).toString() == runningValue);
-        const bool isEnabled = dependTargets.contains(name) || Service::isEnabled(name);
+        const bool isEnabled = (!isUserService && dependTargets.contains(name))
+            || enabledServices.contains(name);
 
-        services.append(QSharedPointer<Service>::create(name, isRunning, isEnabled));
+        services.append(QSharedPointer<Service>::create(name, isRunning, isEnabled, isUserService));
     }
     names = QStringList(nameSet.begin(), nameSet.end());
 }
 
-void MainWindow::processSystemdMaskedServices(QStringList &names)
+void MainWindow::processSystemdMaskedServices(QStringList &names, bool isUserService)
 {
-    const auto masked = cmd.getOut("systemctl list-unit-files --type=service --state=masked -o json").trimmed();
+    QString cmdStr = "systemctl list-unit-files --type=service --state=masked -o json";
+    if (isUserService) [[unlikely]] {
+        cmdStr = "systemctl --user list-unit-files --type=service --state=masked -o json";
+    }
+    const auto masked = cmd.getOut(cmdStr).trimmed();
     auto doc = QJsonDocument::fromJson(masked.toUtf8());
     if (!doc.isArray()) {
         qDebug() << "JSON data is not an array for masked services.";
@@ -296,26 +497,30 @@ void MainWindow::processSystemdMaskedServices(QStringList &names)
     nameSet.reserve(nameSet.size() + jsonArray.size());
 
     const QLatin1String unitFileKey("unit_file");
-    const QLatin1String dotSeparator(".");
 
     for (const auto &value : jsonArray) {
-        if (!value.isObject()) {
+        if (!value.isObject()) [[unlikely]] {
             continue;
         }
         const auto obj = value.toObject();
-        const QString name = obj.value(unitFileKey).toString().section(dotSeparator, 0, 0);
+        const auto nameOpt = sanitizeServiceName(obj.value(unitFileKey).toString());
 
-        if (name.isEmpty() || nameSet.contains(name)) {
+        if (!nameOpt || nameSet.contains(*nameOpt)) [[unlikely]] {
             continue;
         }
+
+        const QString &name = *nameOpt;
         nameSet.insert(name);
-        services.append(QSharedPointer<Service>::create(name));
+        services.append(QSharedPointer<Service>::create(name, false, false, isUserService));
     }
     names = QStringList(nameSet.begin(), nameSet.end());
 }
 
 void MainWindow::displayServices() noexcept
 {
+    // Cancel any pending tooltips since items are being recreated
+    cancelPendingTooltip();
+
     ui->listServices->blockSignals(true);
     ui->listServices->clear();
 
@@ -327,25 +532,37 @@ void MainWindow::displayServices() noexcept
 
     ui->listServices->setUpdatesEnabled(false);
 
-    const bool isFilterAll = currentFilter.isEmpty() || currentFilter == tr("All services");
+    const bool isFilterAll = currentFilter.isEmpty() || currentFilter == tr("System services");
     const bool isFilterRunning = currentFilter == tr("Running services");
     const bool isFilterEnabled = currentFilter == tr("Services enabled at boot");
     const bool isFilterDisabled = currentFilter == tr("Services disabled at boot");
+    const bool isFilterUser = currentFilter == tr("User services");
+    const bool isFilterSystem = currentFilter == tr("System services");
 
     for (const auto &service : services) {
-        const QString serviceName = service->getName().toLower();
+        if (!service || !service.get()) [[unlikely]] {
+            continue;
+        }
+        QString serviceName = service->getName();
+        // Ensure service name is valid to prevent crashes
+        if (serviceName.isNull() || serviceName.isEmpty()) [[unlikely]] {
+            continue;
+        }
+        serviceName = serviceName.toLower();
         const bool isRunning = service->isRunning();
         const bool isEnabled = service->isEnabled();
+        const bool isUserService = service->isUserService();
 
         // Check search criteria
-        if (!searchText.isEmpty() && !serviceName.startsWith(searchText)
+        if (!searchText.isEmpty() && !serviceName.contains(searchText, Qt::CaseInsensitive)
             && !(serviceName == QLatin1String("smbd") && incrementalSearchPatterns.contains(searchText))) {
             continue;
         }
 
         // Check filter criteria
         if ((isFilterRunning && !isRunning) || (isFilterEnabled && !isEnabled) || (isFilterDisabled && isEnabled)
-            || (!isFilterAll && !isFilterRunning && !isFilterEnabled && !isFilterDisabled)) {
+            || (isFilterUser && !isUserService) || (isFilterSystem && isUserService)
+            || (!isFilterAll && !isFilterRunning && !isFilterEnabled && !isFilterDisabled && !isFilterUser && !isFilterSystem)) {
             continue;
         }
 
@@ -357,7 +574,11 @@ void MainWindow::displayServices() noexcept
         }
 
         // Create item and add it directly to the list widget
-        auto *item = new QListWidgetItem(serviceName, ui->listServices);
+        QString displayName = serviceName;
+        if (isUserService) [[unlikely]] {
+            displayName = tr("[User] ") % serviceName;
+        }
+        auto *item = new QListWidgetItem(displayName, ui->listServices);
         item->setData(Qt::UserRole, QVariant::fromValue(service.get()));
         item->setForeground(isRunning ? runningColor : (isEnabled ? enabledColor : Qt::black));
     }
@@ -383,11 +604,11 @@ void MainWindow::pushAbout_clicked()
 {
     hide();
     displayAboutMsgBox(
-        tr("About %1") + tr("MX Service Manager"),
-        R"(<p align="center"><b><h2>MX Service Manager</h2></b></p><p align="center">)" + tr("Version: ")
-            + QApplication::applicationVersion() + "</p><p align=\"center\"><h3>" + tr("Service and daemon manager")
-            + R"(</h3></p><p align="center"><a href="http://mxlinux.org">http://mxlinux.org</a><br /></p><p align="center">)"
-            + tr("Copyright (c) MX Linux") + "<br /><br /></p>",
+        tr("About %1") % tr("MX Service Manager"),
+        R"(<p align="center"><b><h2>MX Service Manager</h2></b></p><p align="center">)" % tr("Version: ")
+            % QApplication::applicationVersion() % "</p><p align=\"center\"><h3>" % tr("Service and daemon manager")
+            % R"(</h3></p><p align="center"><a href="http://mxlinux.org">http://mxlinux.org</a><br /></p><p align="center">)"
+            % tr("Copyright (c) MX Linux") % "<br /><br /></p>",
         "/usr/share/doc/mx-service-manager/license.html", tr("%1 License").arg(windowTitle()));
 
     show();
